Public error types for the types module.
These errors are safe to expose to other modules and consumers.
Enums
- Types
Error - Errors that can be returned by the
TypesClient.
Public error types for the types module.
These errors are safe to expose to other modules and consumers.
TypesClient.