pub enum TypesError {
NotReady,
RegistrationFailed(String),
Internal(String),
}Expand description
Errors that can be returned by the TypesClient.
Variants
NotReady
Core types are not yet registered.
RegistrationFailed(String)
Failed to register core types.
Internal(String)
An internal error occurred.
Implementations
Sourceimpl TypesError
impl TypesError
Sourcepub fn registration_failed(message: impl Into<String>) -> Self
pub fn registration_failed(message: impl Into<String>) -> Self
Creates a RegistrationFailed error.
Sourcepub const fn is_not_ready(&self) -> bool
pub const fn is_not_ready(&self) -> bool
Returns true if this is a not ready error.
Sourcepub const fn is_registration_failed(&self) -> bool
pub const fn is_registration_failed(&self) -> bool
Returns true if this is a registration failed error.